@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  */
@@ -20,8 +20,9 @@ char *strndup(const char *str, size_t n) {
     size_t len;
     char *copy;
 
-    for (len = 0; len < n && str[len]; len++)
+    for (len = 0; len < n && str[len]; len++) {
         continue;
+    }
 
     copy = smalloc(len + 1);
     memcpy(copy, str, len);
