@@ -280,10 +280,8 @@ static void handle_mapping_notify(xcb_mapping_notify_event_t *event) {
  * A new window appeared on the screen (=was mapped), so let’s manage it.
  *
  */
-static void handle_map_request(xcb_map_request_event_t *event) {
-    xcb_get_window_attributes_cookie_t cookie;
-
-    cookie = xcb_get_window_attributes_unchecked(conn, event->window);
+static void handle_map_request(const xcb_map_request_event_t *event) {
+    xcb_get_window_attributes_cookie_t cookie = xcb_get_window_attributes_unchecked(conn, event->window);
 
     DLOG("window = 0x%08x, serial is %d.\n", event->window, event->sequence);
     add_ignore_event(event->sequence, -1);
@@ -629,7 +627,7 @@ static bool handle_windowname_change_legacy(Con *con, xcb_get_property_reply_t *
 static bool handle_windowrole_change(Con *con, xcb_get_property_reply_t *prop) {
     window_update_role(con->window, prop);
 
-    con = remanage_window(con);
+    remanage_window(con);
 
     return true;
 }
@@ -895,6 +893,7 @@ static void handle_client_message(xcb_client_message_event_t *event) {
                 con->sticky = true;
                 ewmh_update_sticky(con->window->id, true);
                 output_push_sticky_windows(focused);
+                run_assignments(con->window);
             }
         } else {
             Con *ws = ewmh_get_workspace_by_index(index);
@@ -1304,25 +1303,6 @@ static bool handle_strut_partial_change(Con *con, xcb_get_property_reply_t *prop
     return true;
 }
 
-/*
- * Handles the _I3_FLOATING_WINDOW property to properly run assignments for
- * floating window changes.
- *
- * This is needed to correctly run the assignments after changes in floating
- * windows which are triggered by user commands (floating enable | disable). In
- * that case, we can't call run_assignments because it will modify the parser
- * state when it needs to parse the user-specified action, breaking the parser
- * state for the original command.
- *
- */
-static bool handle_i3_floating(Con *con, xcb_get_property_reply_t *prop) {
-    DLOG("floating change for con %p\n", con);
-
-    remanage_window(con);
-
-    return true;
-}
-
 static bool handle_windowicon_change(Con *con, xcb_get_property_reply_t *prop) {
     window_update_icon(con->window, prop);
 
@@ -1352,7 +1332,6 @@ static struct property_handler_t property_handlers[] = {
     {0, 128, handle_class_change},
     {0, UINT_MAX, handle_strut_partial_change},
     {0, UINT_MAX, handle_window_type},
-    {0, UINT_MAX, handle_i3_floating},
     {0, 128, handle_machine_change},
     {0, 5 * sizeof(uint64_t), handle_motif_hints_change},
     {0, UINT_MAX, handle_windowicon_change}};
@@ -1376,10 +1355,9 @@ void property_handlers_init(void) {
     property_handlers[7].atom = XCB_ATOM_WM_CLASS;
     property_handlers[8].atom = A__NET_WM_STRUT_PARTIAL;
     property_handlers[9].atom = A__NET_WM_WINDOW_TYPE;
-    property_handlers[10].atom = A_I3_FLOATING_WINDOW;
-    property_handlers[11].atom = XCB_ATOM_WM_CLIENT_MACHINE;
-    property_handlers[12].atom = A__MOTIF_WM_HINTS;
-    property_handlers[13].atom = A__NET_WM_ICON;
+    property_handlers[10].atom = XCB_ATOM_WM_CLIENT_MACHINE;
+    property_handlers[11].atom = A__MOTIF_WM_HINTS;
+    property_handlers[12].atom = A__NET_WM_ICON;
 }
 
 static void property_notify(uint8_t state, xcb_window_t window, xcb_atom_t atom) {
