@@ -33,13 +33,17 @@ Con *output_get_content(Con *output) {
 Output *get_output_from_string(Output *current_output, const char *output_str) {
     if (strcasecmp(output_str, "current") == 0) {
         return get_output_for_con(focused);
-    } else if (strcasecmp(output_str, "left") == 0) {
+    }
+    if (strcasecmp(output_str, "left") == 0) {
         return get_output_next_wrap(D_LEFT, current_output);
-    } else if (strcasecmp(output_str, "right") == 0) {
+    }
+    if (strcasecmp(output_str, "right") == 0) {
         return get_output_next_wrap(D_RIGHT, current_output);
-    } else if (strcasecmp(output_str, "up") == 0) {
+    }
+    if (strcasecmp(output_str, "up") == 0) {
         return get_output_next_wrap(D_UP, current_output);
-    } else if (strcasecmp(output_str, "down") == 0) {
+    }
+    if (strcasecmp(output_str, "down") == 0) {
         return get_output_next_wrap(D_DOWN, current_output);
     }
 
@@ -83,13 +87,13 @@ Output *get_output_for_con(Con *con) {
 void output_push_sticky_windows(Con *old_focus) {
     Con *output;
     TAILQ_FOREACH (output, &(croot->focus_head), focused) {
-        Con *workspace, *visible_ws = NULL;
+        Con *visible_ws = NULL;
         GREP_FIRST(visible_ws, output_get_content(output), workspace_is_visible(child));
 
         /* We use this loop instead of TAILQ_FOREACH to avoid problems if the
          * sticky window was the last window on that workspace as moving it in
          * this case will close the workspace. */
-        for (workspace = TAILQ_FIRST(&(output_get_content(output)->focus_head));
+        for (Con *workspace = TAILQ_FIRST(&(output_get_content(output)->focus_head));
              workspace != TAILQ_END(&(output_get_content(output)->focus_head));) {
             Con *current_ws = workspace;
             workspace = TAILQ_NEXT(workspace, focused);
@@ -97,8 +101,7 @@ void output_push_sticky_windows(Con *old_focus) {
             /* Since moving the windows actually removes them from the list of
              * floating windows on this workspace, here too we need to use
              * another loop than TAILQ_FOREACH. */
-            Con *child;
-            for (child = TAILQ_FIRST(&(current_ws->focus_head));
+            for (Con *child = TAILQ_FIRST(&(current_ws->focus_head));
                  child != TAILQ_END(&(current_ws->focus_head));) {
                 Con *current = child;
                 child = TAILQ_NEXT(child, focused);
